math_pip
This is an example Python package created by Rahul Kumar.

It provides additional math operations and utility functions.

Installation
You can install the package via pip:

pip install pack_pip